"use strict";

exports.__esModule = true;
exports.useStyleConfig = useStyleConfig;
exports.useMultiStyleConfig = useMultiStyleConfig;

var _vue = require("vue");

var _vueUtils = require("@chakra-ui/vue-utils");

var _useChakra2 = require("./use-chakra");

function useStyleConfig(themeKey, themingProps, options, userStyleConfig) {
  var _styleConfig$defaultP;

  if (options === void 0) {
    options = {};
  }

  var _useChakra = (0, _useChakra2.useChakra)(),
      theme = _useChakra.theme,
      colorMode = _useChakra.colorMode;

  var themeStyleConfig = (0, _vueUtils.get)(theme, "components." + themeKey);
  var styleConfig = userStyleConfig || themeStyleConfig;
  var mergedProps = (0, _vueUtils.mergeWith)({
    theme: theme,
    colorMode: colorMode
  }, (_styleConfig$defaultP = styleConfig == null ? void 0 : styleConfig.defaultProps) != null ? _styleConfig$defaultP : {}, (0, _vueUtils.filterUndefined)(themingProps));
  return (0, _vue.computed)(function () {
    var _styleConfig$baseStyl, _styleConfig$variants, _styleConfig$variants2, _styleConfig$sizes$me, _styleConfig$sizes;

    var baseStyles = (0, _vueUtils.runIfFn)((_styleConfig$baseStyl = styleConfig.baseStyle) != null ? _styleConfig$baseStyl : {}, mergedProps);
    var variants = (0, _vueUtils.runIfFn)((_styleConfig$variants = (_styleConfig$variants2 = styleConfig.variants) == null ? void 0 : _styleConfig$variants2[mergedProps.variant]) != null ? _styleConfig$variants : {}, mergedProps);
    var sizes = (0, _vueUtils.runIfFn)((_styleConfig$sizes$me = (_styleConfig$sizes = styleConfig.sizes) == null ? void 0 : _styleConfig$sizes[mergedProps.size]) != null ? _styleConfig$sizes$me : {}, mergedProps);
    var styles = (0, _vueUtils.mergeWith)({}, baseStyles, sizes, variants);

    if (options.isMultiPart && styleConfig.parts) {
      styleConfig.parts.forEach(function (part) {
        var _styles$part;

        styles[part] = (_styles$part = styles[part]) != null ? _styles$part : {};
      });
    }

    return styles;
  });
}

function useMultiStyleConfig(themeKey, themingProps) {
  return useStyleConfig(themeKey, themingProps, {
    isMultiPart: true
  });
}
//# sourceMappingURL=use-style-config.js.map