import { DefineComponent, PropType } from 'vue';
import { ResponsiveValue, SystemProps, SystemStyleObject } from '@chakra-ui/styled-system';
import { CSSObject } from '@emotion/css';
import { domElements, DOMElements } from './system.utils';
interface StyleResolverProps extends SystemProps {
    __css?: SystemStyleObject;
    sx?: SystemStyleObject;
    css?: CSSObject;
    noOfLines?: ResponsiveValue<number>;
    isTruncated?: boolean;
    layerStyle?: ResponsiveValue<string>;
    textStyle?: ResponsiveValue<string>;
    apply?: ResponsiveValue<string>;
    componentName?: String;
    label?: string;
    baseStyle?: SystemStyleObject;
    /**
     * User provided styles from component/chakra API
     */
    styles?: SystemStyleObject;
}
interface StyleResolverOptions extends StyleResolverProps {
    truncateStyle?: CSSObject;
    theme?: any;
}
declare const chakraProps: {
    __css: PropType<import("@chakra-ui/styled-system").CSSWithMultiValues | (import("@chakra-ui/styled-system").CSSWithMultiValues & import("@chakra-ui/styled-system").RecursivePseudo<import("@chakra-ui/styled-system").CSSWithMultiValues>) | (import("@chakra-ui/styled-system").CSSWithMultiValues & import("@chakra-ui/styled-system").RecursiveCSSSelector<import("@chakra-ui/styled-system").CSSWithMultiValues>) | undefined>;
    sx: PropType<import("@chakra-ui/styled-system").CSSWithMultiValues | (import("@chakra-ui/styled-system").CSSWithMultiValues & import("@chakra-ui/styled-system").RecursivePseudo<import("@chakra-ui/styled-system").CSSWithMultiValues>) | (import("@chakra-ui/styled-system").CSSWithMultiValues & import("@chakra-ui/styled-system").RecursiveCSSSelector<import("@chakra-ui/styled-system").CSSWithMultiValues>) | undefined>;
    css: PropType<CSSObject | undefined>;
    noOfLines: PropType<number | import("@chakra-ui/styled-system/dist/types/utils").ResponsiveArray<number> | Partial<Record<string, number>> | undefined>;
    baseStyle: PropType<import("@chakra-ui/styled-system").CSSWithMultiValues | (import("@chakra-ui/styled-system").CSSWithMultiValues & import("@chakra-ui/styled-system").RecursivePseudo<import("@chakra-ui/styled-system").CSSWithMultiValues>) | (import("@chakra-ui/styled-system").CSSWithMultiValues & import("@chakra-ui/styled-system").RecursiveCSSSelector<import("@chakra-ui/styled-system").CSSWithMultiValues>) | undefined>;
    isTruncated: PropType<boolean | undefined>;
    layerStyle: PropType<string | import("@chakra-ui/styled-system/dist/types/utils").ResponsiveArray<string> | Partial<Record<string, string>> | undefined>;
    textStyle: PropType<string | import("@chakra-ui/styled-system/dist/types/utils").ResponsiveArray<string> | Partial<Record<string, string>> | undefined>;
    apply: PropType<string | import("@chakra-ui/styled-system/dist/types/utils").ResponsiveArray<string> | Partial<Record<string, string>> | undefined>;
    label: PropType<string | undefined>;
};
export declare type ChakraBaseComponentProps = typeof chakraProps;
/**
 * Chakra factory serves as an object of chakra enabled HTML elements,
 * and also a function that can be used to enable custom component receive chakra's style props.
 * @param tag Tag or Component
 * @param options resolver options
 *
 * How does it work?
 *
 * 1. Components returned from the chakra factory can be styled after consuming them
 *    @example
 *    ```js
 *    const Form = chakra('form') // returns a VNode you can use in the template directly
 *    ```
 *
 * 2. Chakra components can directly be styled upon creation using the options object of type `StyleResolverProps`
 *    This resolves style object for component styles defined in the theme.
 *
 *    Styling components using the chakra factory function can be done using the following keys from the theme:
 *    - `baseStyle`
 *    - `layerStyle`
 *    - `textStyle`
 *
 *    @example
 *    ```js
 *    const MyCustomButton = chakra('button', {
 *     baseStyle: {
         bg: 'papayawhip,
         color: 'red.500,
         px: 4,
         py: 3
       }
 *    })
 *    ```
 *    ```html
 *    <my-custom-button>Hello Papaya Button</my-custom-button>
 *    ```
 *
 *    See more about the style resolution in the `resolveStyles` function.
 *
 * 3. Chakra components created and styled using the `chakra` factory can be overriden in the template by applying
 *    style properties directly
 *
 *    @example
 *    ```html
 *    <my-custom-button bg="blue.400">
 *      Papaya button goes blue
 *    </my-custom-button>
 *    ```
 */
export declare const chakra: IChakraFactory;
export declare const resolveStyles: (resolvers?: StyleResolverOptions) => CSSObject;
declare type IChakraFactory = {
    [key in DOMElements]: DefineComponent | JSX.Element;
} & {
    (tag: DOMElements, options?: StyleResolverProps): DefineComponent;
};
export { domElements };
